@@ -11,6 +11,8 @@ from .parsers import (
     ascii_alpha
     )
 
+from .openfoam import foam_file
+
 logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 __author__ = "Johan Hidding"
@@ -18,4 +20,4 @@ __email__ = "j.hidding@esciencecenter.nl"
 __all__ = ["Cursor", "parse_bytes", "sequence", "push", "pop",
            "flush", "flush_decode", "many_char", "many_char_0",
            "some_char", "some_char_0",
-           "char", "ascii_alpha"]
+           "char", "ascii_alpha", "foam_file"]
