@@ -2,10 +2,10 @@ import functools
 
 
 def decorator(f):
-    """Creates a paramatric decorator from a function. The resulting decorator
+    """Creates a parametric decorator from a function. The resulting decorator
     will optionally take keyword arguments."""
     @functools.wraps(f)
-    def decoratored_function(*args, **kwargs):
+    def decorated_function(*args, **kwargs):
         if args and len(args) == 1:
             return f(*args, **kwargs)
 
@@ -15,4 +15,4 @@ def decorator(f):
 
         return lambda g: f(g, **kwargs)
 
-    return decoratored_function
+    return decorated_function
